/*
 * Copyright (C) 1998   Warren Jasper
 * All rights reserved.
 *
 */

/*
 * c9513.h  Genearl header file for the CIO-CTR05
 */

#define CTR05_BASE       0x320    /* base addr (set on board) */
#define CTR05_IRQ           -1    /*  irq      (set on board) */

#ifndef DEFAULT_MAJOR_DEV
#define DEFAULT_MAJOR_DEV  40    /* Default Major Device Number */
#endif

#define BOARD_SIZE       0x4     /* uses 4 bytes of registers   */
#define NUM_COUNTERS     0x5     /* 5 counters on the chip      */


/* General Defines */
#define TRUE  1
#define FALSE 0
#define ENABLED  1
#define DISABLED 0


/* 9513 counter command codes */
#define ARM           0x20
#define LOAD          0x40
#define LOAD_ARM      0x60
#define DISARM_LATCH  0x80
#define LATCH         0xa0
#define DISARM        0xc0
#define SET_OUTPUT    0xe8
#define CLEAR_OUTPUT  0xe0
#define MASTER_RESET  0xff

/* Select Registers */
#define MODE_REG      0x0
#define LOAD_REG      0x8
#define HOLD_REG      0x10

/* Counters */
#define CTR4 4
#define CTR5 5

/* Counter Select bits */
#define CTR1_BIT    0x1
#define CTR2_BIT    0x2
#define CTR3_BIT    0x4
#define CTR4_BIT    0x8
#define CTR5_BIT    0x10

/* I/O Register locations */

#define DATA_REG      (CTR05_BASE)      /* 9513 Data Register    */
#define CMD_REG       (CTR05_BASE + 1)  /* 9513 Command Register */
#define DIO_IN        (CTR05_BASE + 2)  /* Digital Input Port    */
#define DIO_OUT       (CTR05_BASE + 3)  /* Digital Output Port   */

/* Data structures for the ctr05 board */

typedef struct BOARD_REC {
  int busy;            /* busy = TRUE, free = FALSE              */
  int irq;             /* board irq                              */
  WORD gateInterval;   /* time in ms that the counter will count */
  WORD base;           /* board irq                              */
  WORD mm;             /* Master Mode Control Register           */  
  int  useCounter;     /* counts the nubmer of freq counters     */
} BoardRec;

/* Values kept for each channel. */

typedef struct COUNTER_REC {
  int  open;            /* Is channel device open()         */
  LONG count;           /* Number of samples requested      */
  WORD cm;              /* Counter Mode Register            */
  BYTE mode;            /*                                  */
  BYTE chan;            /* Counter number                   */
} CounterRec;

typedef struct DIO_CHANNEL_REC {
  int  open;              /* Is channel device open()    */
} DIO_ChanRec;















